@@ -9,22 +9,25 @@ use crate::arena::Event;
 use crate::arena::PIPEBLOCK;
 use crate::arena::{lca};
 
-/// Map a transfert in gene  tree to the species tree
-pub fn map_transfer(transfers: Vec<(String,String)> , parasite_tree: &mut ArenaTree<String>) -> Vec<(String,String)> {
-        let mut  map_transfers = vec![];
-        for (start, end) in transfers {
-            let map_start = parasite_tree.get_index(start.to_string())
-                .expect("[map_transfer] unable to find start node");
-            let map_start = parasite_tree.arena[map_start].location.to_string();
-            let map_end = parasite_tree.get_index(end.to_string())
-                .expect("[map_transfer] unable to find end node");
-            let map_end = parasite_tree.arena[map_end].location.to_string();
-            map_transfers.push((map_start,map_end));
-        }
-        map_transfers
-}
+// Functions
+// =========
 
-// map a transfert in gene  tree to the species trees
+/// Map a transfer in gene  tree to the species tree.
+pub fn map_transfer(transfers: Vec<(String,String)> ,
+    parasite_tree: &mut ArenaTree<String>) -> Vec<(String,String)> {
+    let mut  map_transfers = vec![];
+    for (start, end) in transfers {
+        let map_start = parasite_tree.get_index(start.to_string())
+            .expect("[map_transfer] unable to find start node");
+        let map_start = parasite_tree.arena[map_start].location.to_string();
+        let map_end = parasite_tree.get_index(end.to_string())
+            .expect("[map_transfer] unable to find end node");
+        let map_end = parasite_tree.arena[map_end].location.to_string();
+        map_transfers.push((map_start,map_end));
+    }
+    map_transfers
+}
+/// Map a transfer from a gene tree to the species trees.
 pub fn map_transfer_mul(transfers: Vec<(String,String)> ,
     parasite_trees: &mut  Vec<ArenaTree<String>>) -> Vec<(String,String)> {
     let mut  map_transfers = vec![];
@@ -73,8 +76,7 @@ pub fn map_transfer_mul(transfers: Vec<(String,String)> ,
         }
     map_transfers
 }
-
-///  Get the transfers in a gene tree
+///  Get the transfers in a gene tree.
 pub fn get_gtransfer(gene_tree: &mut ArenaTree<String>) -> Vec<(String,String)> {
     let mut  transfers = vec![];
     for index in  &gene_tree.arena {
@@ -91,8 +93,7 @@ pub fn get_gtransfer(gene_tree: &mut ArenaTree<String>) -> Vec<(String,String)>
     };
     transfers
 }
-
-/// Map a reconciled species tree to a pipe species tree
+/// Map a reconciled species tree to a pipe species tree.
 pub fn map_parasite_g2s(para_as_species: &mut ArenaTree<String>,para_as_gene: &mut ArenaTree<String>,) {
     // Explore pipe species tree
     for index in  &mut para_as_species.arena {
@@ -112,8 +113,10 @@ pub fn map_parasite_g2s(para_as_species: &mut ArenaTree<String>,para_as_gene: &m
                     &Event::BifurcationOut => Event::BifurcationOut,
                     &Event::Loss => Event::Loss,
                     &Event::Leaf => Event::Leaf,
-                    _ => {eprintln!("Event {:?} not selected",e);
-                         Event::Undef},
+                    _ => {
+                        eprintln!("Event {:?} not selected",e);
+                        Event::Undef
+                        },
                 };
             },
             Err(_err) => {
@@ -122,8 +125,7 @@ pub fn map_parasite_g2s(para_as_species: &mut ArenaTree<String>,para_as_gene: &m
         }
     }
 }
-
-/// Map a pipe species tree to a reconciled species tree
+/// Map a pipe species tree to a reconciled species tree.
 pub fn map_parasite_s2g(para_as_species: &mut ArenaTree<String>,
     para_as_gene: &mut ArenaTree<String>,
     gene_trees : &mut std::vec::Vec<ArenaTree<String>>) {
@@ -212,11 +214,9 @@ pub fn map_parasite_s2g(para_as_species: &mut ArenaTree<String>,
                         para_as_species.arena[new_leaf].nbg = nbg;
                         para_as_species.arena[j].nbg = 0;
                         para_as_species.arena[j].nodes = [].to_vec();
-
                         info!("[map_parasite_s2g] parent species node is now #{} {:?}",j,para_as_species.arena[j]);
                         info!("[map_parasite_s2g] added species leave is now #{} {:?}",new_leaf,para_as_species.arena[new_leaf]);
                         info!("[map_parasite_s2g] the reconciled species node is still {:?}",index);
-
                         // Now we modify the location of  the gene nodes (gene species maping)
                         // We may have to add  a node in  the gene tree for j
                         // gene nodes associated to the new rec species node:
@@ -241,7 +241,6 @@ pub fn map_parasite_s2g(para_as_species: &mut ArenaTree<String>,
                             info!("[map_parasite_s2g] Modify gene tree number {}",*ng);
                             info!("[map_parasite_s2g] Redefine location of the node {}.",nn);
                             info!("[map_parasite_s2g] Previous {:?}:", &gene_trees[*ng].arena[*nn]);
-
                             gene_trees[*ng].arena[*nn].location = para_as_species.arena[new_leaf].name.to_string();
                             info!("[map_parasite_s2g] New {:?}:", &gene_trees[*ng].arena[*nn]);
                             // In case the node is not a root (I expect index 0 is root, maybe this
@@ -315,7 +314,6 @@ pub fn map_parasite_s2g(para_as_species: &mut ArenaTree<String>,
                             para_as_species.arena[node].nbg = para_as_species.arena[node].nbg + 1;
                             para_as_species.arena[node].nodes.push((ng,node2)) ;
                             info!("[map_parasite_s2g] Species node is now {:?}",para_as_species.arena[node]);
-
                         }
                     },
                     _ => {
@@ -419,14 +417,11 @@ pub fn map_parasite_s2g(para_as_species: &mut ArenaTree<String>,
                         }
                     },
                 };
-
-
             },
         }
     }
 }
-
-/// Map gene trees to  host tree
+/// Map gene trees to a host tree.
 pub fn map_gene_host(gene_trees: &mut Vec<ArenaTree<String>>, tree_para_pipes:  &mut Vec<ArenaTree<String>>, tree_host_pipe:&mut ArenaTree<String>) {
     // unmap the host tree
     let mut j = 0;
@@ -545,24 +540,21 @@ pub fn map_gene_host(gene_trees: &mut Vec<ArenaTree<String>>, tree_para_pipes:
     }
     // println!("DEBUG  [map_gene_host] FINAL HOST = {:?}",tree_host_pipe)
 }
-
-//  get the trasnsfers in a gene tree
+/// Get the transfers in a gene tree.
 #[allow(dead_code)]
 pub fn select_transfer(transfers: & Vec<(String,String)>,species_tree: &mut ArenaTree<String>) -> Vec<(String,String)> {
-let mut  selected = vec![];
-for (start,end) in transfers {
+	let mut  selected = vec![];
+	for (start,end) in transfers {
     let s = species_tree.get_index(start.to_string()).expect("[select_transfer] Unable fo find start");
-    let e = species_tree.get_index(end.to_string()).expect("[select_transfer] Unable fo find start");
-    let ancestor = lca(species_tree,s,e);
-    if (ancestor != s) && (ancestor != e) {
-        selected.push((start.clone(),end.clone()));
+        let e = species_tree.get_index(end.to_string()).expect("[select_transfer] Unable fo find start");
+        let ancestor = lca(species_tree,s,e);
+        if (ancestor != s) && (ancestor != e) {
+            selected.push((start.clone(),end.clone()));
+        }
     }
+    selected
 }
-selected
-
-}
-
-//  get the trasnsfers in a gene tree
+//  Under development
 pub fn optimisation(transfer: & (String,String),species_tree: &mut ArenaTree<String>) -> usize {
     info!("[optimisation]");
     let  (start,end) = transfer;
@@ -680,7 +672,7 @@ pub fn optimisation(transfer: & (String,String),species_tree: &mut ArenaTree<Str
     }
     ancestor
 }
-
+// Under development.
 pub fn check_optimisation(transfer: & (String,String), species_tree: &mut ArenaTree<String>,node: usize) {
     let  (start,end) = transfer;
     info!("[check_optimisation]");
@@ -738,7 +730,7 @@ pub fn check_optimisation(transfer: & (String,String), species_tree: &mut ArenaT
         }
     }
 }
-
+// Under development.
 pub fn classify_transfer(transfer: & (String,String),species_tree: &mut ArenaTree<String>, index: & usize)  {
     let  (start,end) = transfer;
     info!("[classify_transfer] Transfer {}->{}",start,end);
@@ -765,7 +757,7 @@ pub fn classify_transfer(transfer: & (String,String),species_tree: &mut ArenaTre
     parent = species_tree.arena[p].parent;
     };
 }
-
+// Under development.
 pub fn reorder_transfers(species_tree: &mut ArenaTree<String>, node:  usize, ordered: &mut Vec<usize> ) {
     let tr = &species_tree.arena[node].transfers;
     info!("[reorder_transfers_transfer] Transfers at {} =  {:?}", &species_tree.arena[node].name,tr);
